__version__ = '0.0.1'
__license__ = 'MIT'
__author__ = 'Andrey Doroschenko'
__email__ = 'dorosch.github.io@yandex.ru'
__url__ = 'https://github.com/dorosch/django-admin-framework'

default_app_config = 'admin_framework.apps.AdminFrameworkAppConfig'
