from django import apps


class AdminFrameworkAppConfig(apps.AppConfig):
    """Settings class for admin framework application."""

    name = 'admin_framework'
    verbose_name = 'Django Admin Framework'
